==> minecolonies-1.10.2-0.6.3191-sources.jar: com/minecolonies/coremod/commands/DeleteColonyCommand.java <==
package com.minecolonies.coremod.commands;

import com.minecolonies.coremod.colony.Colony;
import com.minecolonies.coremod.colony.ColonyManager;
import com.minecolonies.coremod.colony.IColony;
import com.minecolonies.coremod.colony.permissions.Permissions;
import com.mojang.authlib.GameProfile;
import net.minecraft.command.CommandException;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.TextComponentString;
import org.jetbrains.annotations.NotNull;

import javax.annotation.Nullable;
import java.util.Collections;
import java.util.List;
import java.util.UUID;

import static com.minecolonies.coremod.commands.AbstractSingleCommand.Commands.DELETECOLONY;

import com.minecolonies.coremod.commands.AbstractSingleCommand.Commands;

/**
 * List all colonies.
 */
public class DeleteColonyCommand extends AbstractSingleCommand
{

    public static final  String DESC                       = "delete";
    private static final String NO_COLONY_FOUND_MESSAGE_ID = "Colony with ID %d not found.";
    private static final String NO_ARGUMENTS               = "Please define a colony to delete";

    /**
     * Initialize this SubCommand with it's parents.
     *
     * @param parents an array of all the parents.
     */
    public DeleteColonyCommand(@NotNull final String... parents)
    {
        super(parents);
    }

    @NotNull
    @Override
    public String getCommandUsage(@NotNull final ICommandSender sender)
    {
        return super.getCommandUsage(sender) + "<ColonyId|OwnerName>";
    }

    @Override
    public void execute(@NotNull final MinecraftServer server, @NotNull final ICommandSender sender, @NotNull final String... args) throws CommandException
    {
        if(args.length == 0)
        {
            sender.func_174793_f().func_145747_a(new TextComponentString(NO_ARGUMENTS));
            return;
        }

        final int colonyId;
        if(args.length == 0)
        {
            IColony colony = null;
            if(sender instanceof EntityPlayer)
            {
                colony = ColonyManager.getIColonyByOwner(((EntityPlayer) sender).field_70170_p, (EntityPlayer) sender);
            }

            if(colony == null)
            {
                sender.func_174793_f().func_145747_a(new TextComponentString(NO_ARGUMENTS));
                return;
            }
            colonyId = colony.getID();
        }
        else
        {
            colonyId = getIthArgument(args, 0, -1);
        }

        final EntityPlayer player = (EntityPlayer) sender;
        if (!canPlayerUseCommand (player, Commands.valueOf("DELETECOLONY"), colonyId))
        {
            sender.func_174793_f().func_145747_a(new TextComponentString(NOT_PERMITTED));
            return;
        }

        final Colony colony = ColonyManager.getColony(colonyId);

        if(colony == null)
        {
            sender.func_174793_f().func_145747_a(new TextComponentString(NO_COLONY_FOUND_MESSAGE_ID));
            return;
        }

        if(sender instanceof EntityPlayer)
        {
            if (canPlayerUseCommand(player, DELETECOLONY, colonyId))
            {
                server.func_152344_a(() -> ColonyManager.deleteColony(colony.getID()));
                return;
            }
            else
            {
                sender.func_174793_f().func_145747_a(new TextComponentString(NOT_PERMITTED));
                return;
            }
        }

        server.func_152344_a(() -> ColonyManager.deleteColony(colony.getID()));
    }

    @Override
    public boolean canRankUseCommand(@NotNull final Colony colony, @NotNull final EntityPlayer player)
    {
        return colony.getPermissions().getRank(player).equals(Permissions.Rank.OWNER);
    }

    @NotNull
    private static UUID getUUIDFromName(@NotNull final ICommandSender sender, @NotNull final String... args)
    {
        final MinecraftServer tempServer = sender.func_130014_f_().func_73046_m();
        if (tempServer != null)
        {
            final GameProfile profile = tempServer.func_152358_ax().func_152655_a(args[0]);
            if (profile != null)
            {
                return profile.getId();
            }
        }
        return null;
    }

    @NotNull
    @Override
    public List<String> getTabCompletionOptions(
                                                 @NotNull final MinecraftServer server,
                                                 @NotNull final ICommandSender sender,
                                                 @NotNull final String[] args,
                                                 @Nullable final BlockPos pos)
    {
        return Collections.emptyList();
    }

    @Override
    public boolean isUsernameIndex(@NotNull final String[] args, final int index)
    {
        return index == 0
                 && args.length > 0
                 && !args[0].isEmpty()
                 && getIthArgument(args, 0, Integer.MAX_VALUE) == Integer.MAX_VALUE;
    }
}

==> minecolonies-1.10.2-0.6.3386-sources.jar: com/minecolonies/coremod/commands/DeleteColonyCommand.java <==
package com.minecolonies.coremod.commands;

import com.minecolonies.coremod.colony.Colony;
import com.minecolonies.coremod.colony.ColonyManager;
import com.minecolonies.coremod.colony.IColony;
import com.minecolonies.coremod.colony.permissions.Permissions;
import com.mojang.authlib.GameProfile;
import net.minecraft.command.CommandException;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.text.TextComponentString;
import org.jetbrains.annotations.NotNull;

import javax.annotation.Nullable;
import java.util.Collections;
import java.util.List;
import java.util.UUID;

import static com.minecolonies.coremod.commands.AbstractSingleCommand.Commands.DELETECOLONY;

/**
 * List all colonies.
 */
public class DeleteColonyCommand extends AbstractSingleCommand
{

    public static final  String DESC                       = "delete";
    private static final String NO_COLONY_FOUND_MESSAGE_ID = "Colony with ID %d not found.";
    private static final String NO_ARGUMENTS               = "Please define a colony to delete";

    /**
     * Initialize this SubCommand with it's parents.
     *
     * @param parents an array of all the parents.
     */
    public DeleteColonyCommand(@NotNull final String... parents)
    {
        super(parents);
    }

    @NotNull
    @Override
    public String getCommandUsage(@NotNull final ICommandSender sender)
    {
        return super.getCommandUsage(sender) + "<ColonyId|OwnerName>";
    }

    @Override
    public void execute(@NotNull final MinecraftServer server, @NotNull final ICommandSender sender, @NotNull final String... args) throws CommandException
    {
        final int colonyId;

        if(args.length == 0)
        {
            IColony colony = null;
            if(sender instanceof EntityPlayer)
            {
                colony = ColonyManager.getIColonyByOwner(((EntityPlayer) sender).field_70170_p, (EntityPlayer) sender);
            }

            if(colony == null)
            {
                sender.func_174793_f().func_145747_a(new TextComponentString(NO_ARGUMENTS));
                return;
            }
            colonyId = colony.getID();
        }
        else
        {
            colonyId = getIthArgument(args, 0, -1);
        }

        final Colony colony = ColonyManager.getColony(colonyId);
        if(colony == null)
        {
            sender.func_174793_f().func_145747_a(new TextComponentString(NO_COLONY_FOUND_MESSAGE_ID));
            return;
        }

        if(sender instanceof EntityPlayer)
        {
            final EntityPlayer player = (EntityPlayer) sender;
            if (!canPlayerUseCommand(player, DELETECOLONY, colonyId))
            {
                sender.func_174793_f().func_145747_a(new TextComponentString(NOT_PERMITTED));
                return;
            }
        }

        server.func_152344_a(() -> ColonyManager.deleteColony(colony.getID()));
    }

    @Override
    public boolean canRankUseCommand(@NotNull final Colony colony, @NotNull final EntityPlayer player)
    {
        return colony.getPermissions().getRank(player).equals(Permissions.Rank.OWNER);
    }

    @NotNull
    private static UUID getUUIDFromName(@NotNull final ICommandSender sender, @NotNull final String... args)
    {
        final MinecraftServer tempServer = sender.func_130014_f_().func_73046_m();
        if (tempServer != null)
        {
            final GameProfile profile = tempServer.func_152358_ax().func_152655_a(args[0]);
            if (profile != null)
            {
                return profile.getId();
            }
        }
        return null;
    }

    @NotNull
    @Override
    public List<String> getTabCompletionOptions(
                                                 @NotNull final MinecraftServer server,
                                                 @NotNull final ICommandSender sender,
                                                 @NotNull final String[] args,
                                                 @Nullable final BlockPos pos)
    {
        return Collections.emptyList();
    }

    @Override
    public boolean isUsernameIndex(@NotNull final String[] args, final int index)
    {
        return index == 0
                 && args.length > 0
                 && !args[0].isEmpty()
                 && getIthArgument(args, 0, Integer.MAX_VALUE) == Integer.MAX_VALUE;
    }
}
